@@ -1,234 +1,3 @@
-!***********************************************************************
-!*                                                                     *
-!*                      MACHINE SPECIFIC ROUTINES                      *
-!*                                                                     *
-!***********************************************************************
-!
-      program sabre
-!     version: 04.06.08, 14:04
-!-----------------------------------------------------------------------
-      implicit none
-!-----------------------------------------------------------------------
-      character(len=80) :: input_file, arg_value
-      character(len=20) :: nextarg
-      character(len=80) :: outbuf
-      integer equals_position, ivalue
-      integer iarg, iargc, versionflag, terseflag, inputflag
-      integer length
-      logical error, stop
-      integer ierror
-      integer mxx_size, maxy_size, maxvar_size, maxpar_size
-!-----------------------------------------------------------------------
-!     Main program calls mpi_init, processes any arguments and then
-!     calls the remainder of Sabre to try
-!     to avoid unnecessary memory allocation in MPI master process
-!-----------------------------------------------------------------------
-!---- Initialise MPI
-!-----*************
-      call mpi_init(ierror)
-!-----*************
-!
-      if (ierror /= 0) then
-          write (outbuf,'(a,i9)') ' Error in mpi_init, ierror = ',ierror
-          call wrtlin(outbuf)
-          stop
-      end if
-!
-!    Process any command line arguments
-!
-!
-!     Assign default data space
-!
-      mxx_size = 100000000
-      maxy_size = 500000
-      maxvar_size = 200
-      maxpar_size = 200
-!
-!    Set flags to argument not present
-!
-      versionflag = 0
-      terseflag = 0
-      inputflag = 0
-!
-!     See if there are any program arguments
-!
-      iarg = 0
-    1 continue
-!
-!     Look for argument prefix
-!
-      iarg = iarg + 1
-!
-      if (iarg > iargc()) then
-          go to 2
-      end if
-!
-!-----***********
-      call getarg(iarg,nextarg)
-!-----***********
-!
-!     Convert the argument prefix to lower case
-!     nextarg might actually be the prefix followed immediately by an
-!     = sign and then the value with no separating spaces in which case
-!     only convert the first part (up to the = sign)
-!
-      equals_position = index(nextarg,'=')
-!
-      if (equals_position > 0) then
-!
-!---------**********
-          call lcase(nextarg(1:equals_position-1))
-!---------**********
-!
-      else
-!
-!---------**********
-          call lcase(nextarg)
-!---------**********
-!
-      end if
-!
-!     First look for version number argument. If found, print and stop
-!
-      if (nextarg(1:7) == 'version' .or. nextarg(1:8) == '-version' &
-      .or. nextarg(1:8) == '/version') then
-!
-         versionflag = 1
-!
-      else if (nextarg(1:5) == 'terse' .or. nextarg(1:6) == '-terse' &
-      .or. nextarg(1:6) == '/terse') then
-          terseflag = 1
-      else if (nextarg(1:5) == 'input' .or. nextarg(1:6) == '-input' &
-      .or. nextarg(1:6) == '/input') then
-!
-         inputflag = 1
-!
-!         Try to get the input file name which should follow
-!
-!---------******************
-          call get_arg_value(iarg,nextarg,input_file)
-!---------******************
-!
-!
-      else if (nextarg(1:3) == 'dat' .or. nextarg(1:4) == '-dat' &
-      .or. nextarg(1:4) == '/dat') then
-!
-!---------******************
-          call get_arg_value(iarg,nextarg,arg_value)
-!---------******************
-!
-!---------***********
-          call chaint(arg_value,ivalue,length(arg_value),error)
-!---------***********
-!
-          if (error) then
-              call wrtscr('Invalid value given for DAT')
-              stop
-          else
-!
-              if (ivalue <= 0) then
-                  call wrtscr('DAT value must be greater than zero')
-                  stop
-              else
-                  mxx_size = ivalue
-              end if
-!
-          end if
-!
-      else if (nextarg(1:3) == 'obs' .or. nextarg(1:4) == '-obs' &
-      .or. nextarg(1:4) == '/obs') then
-!
-!---------******************
-          call get_arg_value(iarg,nextarg,arg_value)
-!---------******************
-!
-!---------***********
-          call chaint(arg_value,ivalue,length(arg_value),error)
-!---------***********
-!
-          if (error) then
-              call wrtscr('Invalid value given for OBS')
-              stop
-          else
-!
-              if (ivalue <= 0) then
-                  call wrtscr('OBS value must be greater than zero')
-                  stop
-              else
-                  maxy_size = ivalue
-              end if
-!
-          end if
-!
-      else if (nextarg(1:3) == 'var' .or. nextarg(1:4) == '-var' &
-      .or. nextarg(1:4) == '/var') then
-!
-!---------******************
-          call get_arg_value(iarg,nextarg,arg_value)
-!---------******************
-!
-!---------***********
-          call chaint(arg_value,ivalue,length(arg_value),error)
-!---------***********
-!
-          if (error) then
-              call wrtscr('Invalid value given for VAR')
-              stop
-          else
-!
-               if (ivalue <= 0) then
-                   call wrtscr('VAR value must be greater than zero')
-                   stop
-               else
-                   maxvar_size = ivalue
-               end if
-!
-          end if
-!
-      else if (nextarg(1:3) == 'par' .or. nextarg(1:4) == '-par' &
-      .or. nextarg(1:4) == '/par') then
-!
-!---------******************
-          call get_arg_value(iarg,nextarg,arg_value)
-!---------******************
-!
-!---------***********
-          call chaint(arg_value,ivalue,length(arg_value),error)
-!---------***********
-!
-          if (error) then
-              call wrtscr('Invalid value given for PAR')
-              stop
-          else
-!
-              if (ivalue <= 0) then
-                  call wrtscr('PAR value must be greater than zero')
-                  stop
-              else
-                  maxpar_size = ivalue
-              end if
-!
-          end if
-!
-      end if
-!
-      go to 1
-    2 continue
-!
-!---- Call remainder of Sabre "main program"
-!-----***************
-!
-!    Initialise abnormal stop flag
-!
-      stop = .false.
-!
-      call sabre_main( stop, mxx_size, maxy_size, maxvar_size, maxpar_size, &
-                       versionflag, terseflag, inputflag, input_file )
-!-----***************
-!
-      stop
-!
-      end program sabre
 !
 !***********************************************************************
 !
@@ -1319,80 +1088,4 @@
       return
 !
       end subroutine readob
-!
-!***********************************************************************
-!
-      subroutine get_arg_value(iarg,nextarg,arg_value)
-!-----------------------------------------------------------------------
-      implicit none
-!-----------------------------------------------------------------------
-!     Look for argument value following nextarg
-!     There may be an equals sign separating the two, with or without
-!     spaces
-!-----------------------------------------------------------------------
-      integer :: iarg, iargc, length
-      character(len=*) :: nextarg
-      character(len=*) :: arg_value
-      character(len=80) :: temp
-!-----------------------------------------------------------------------
-!     Look at last character of argument name
-      if (nextarg(length(nextarg):length(nextarg)) == '=') then
-!         If it's an equals sign the next argument should be the value
-          iarg = iarg + 1
-!
-          if (iarg > iargc()) then
-              call wrtscr('No value give for argument '// &
-                          nextarg(1:length(nextarg)))
-              stop
-          end if
-!
-!---------***********
-          call getarg(iarg,arg_value)
-!---------***********
-!
-      else if (index(nextarg,'=') > 0) then
-!         Argument value is actually part of the argument, separated
-!         from the prefix by an equals sign
-          arg_value = nextarg(index(nextarg,'=')+1:length(nextarg))
-      else
-          iarg = iarg + 1
-!
-          if (iarg > iargc()) then
-              call wrtscr('No value give for argument '// &
-                          nextarg(1:length(nextarg)))
-              stop
-          end if
-!
-!---------***********
-          call getarg(iarg,arg_value)
-!---------***********
-!
-          if (length(arg_value) == 1 .and. arg_value == '=') then
-!             Equals sign by itself found so next argument should be
-!             value
-              iarg = iarg + 1
-!
-              if (iarg > iargc()) then
-                  call wrtscr('No value give for argument '// &
-                              nextarg(1:length(nextarg)))
-                  stop
-              end if
-!
-!-------------***********
-              call getarg(iarg,arg_value)
-!-------------***********
-!
-          else if (arg_value(1:1) == '=') then
-!             Argument value is prefixed by equals sign
-              temp = arg_value
-              arg_value = temp(2:length(temp))
-          else
-!             No equals sign prefix so we have just read the argument
-!             value, i.e. nothing more to do
-          end if
-!
-      end if
-!
-      return
-!
-      end subroutine get_arg_value
+
